Skip to contents

Reads a DRIAS climate projection .txt file and computes the mean monthly precipitation (P), potential evapotranspiration (ETP), and water balance (P - ETP) for each projection period.

Usage

drias_etp(txt)

Arguments

txt

character(1). Path to a DRIAS .txt file downloaded from the DRIAS portal

Value

A data.frame with one row per month and period

Details

Invalid climate points (where precipitation or evapotranspiration are entirely equal to zero across all months) are automatically excluded to avoid biased averages.

Examples

if (FALSE) { # \dontrun{
txt <- "indicesRACMO22E_CNRM-CM5.txt"
etp <- drias_etp(txt)
head(etp)
} # }