Create a forest matrice for legal entity from insee code
get_legal_entity.RdGenerates a forest matrice used to store general forest
information (e.g., IDENTIFIANT, PROPRIETAIRE) and cadastral attributes
(CODE_INSEE, PREFIXE, SECTION, NUMERO, LIEU_DIT) for legal
entity.
Arguments
- x
character; Code(s) INSEE or code(s) department (see [Rsequoia2::get_cog())- cache
character; Storage directory. Defaults to the user cache directory (seetools::R_user_dir()).- verbose
logicalIfTRUE, display messages.
Examples
if (FALSE) { # \dontrun{
pm <- get_legal_entity(c("29158", "08185"))
} # }