Extract owner information from PDF
get_owner.RdParses French cadastral PDFs to extract owner details including type, name, and address from property rights sections.
get_owner.RdParses French cadastral PDFs to extract owner details including type, name, and address from property rights sections.