Skip to contents

Computes monthly ombrothermic summaries from raw climatology data over specified rolling periods.

Usage

mf_ombro(clim, periods = c(30, 5))

Arguments

clim

data.frame Raw climatology data from mf_get_climatology()

periods

integer Vector of periods (in years) used to compute averages. Default is c(30, 5).

Value

A data.frame containing monthly averages of temperature and precipitation for each period.

Examples

if (FALSE) { # \dontrun{
ombro <- mf_ombro(clim)
} # }