Skip to contents

Retrieves hypsometric curves line features intersecting and surrounding the project area and writes the resulting layer to disk.

Usage

seq_curves(dirname = ".", verbose = TRUE, overwrite = FALSE)

Arguments

dirname

character Directory where the matrice file is located. Defaults to the current working directory.

verbose

logical If TRUE, display messages.

overwrite

logical If TRUE, file is overwritten.

Value

Invisibly returns a named list of file paths written by seq_write(). Returns NULL invisibly when no hypsometric curves features are found.

Details

Hypsometric curves line features are retrieved using get_curves().

If no hypsometric curves features are found, the function returns NULL invisibly and no file is written.

When features are present, the layer is written to disk using seq_write() with the key "v.curves.line".