Skip to contents

This function is a convenience wrapper around get_infra_poly(), get_infra_line() and get_infra_point(), allowing the user to download all products in one call and automatically write them to the project directory using seq_write().

Usage

seq_infra(dirname = ".", buffer = 1000, verbose = TRUE, overwrite = FALSE)

Arguments

dirname

character Directory where the matrice file is located. Defaults to the current working directory.

buffer

numeric; Buffer around x (in meters) used to enlarge

verbose

logical If TRUE, display messages.

overwrite

logical If TRUE, file is overwritten.

Value

A named list of file paths written by seq_write(), one per hydrographic layer.

Details

Each infrastructure layer is always written to disk using seq_write(), even when it contains no features (nrow == 0).

Informational messages are displayed to indicate whether a layer contains features or is empty.