Skip to contents

Launches the main interactive workflow for Rsequoia2, allowing the user to select a project folder and choose among map layer creation or cartographic tools.

Usage

sequoia2(overwrite = FALSE)

Arguments

overwrite

logical If TRUE, file is overwritten.

Value

Invisibly returns current Sequoia path. The function primarily calls other Rsequoia2 functions.