Skip to contents

Aggregates corrected surface areas from a UA layer by grouping rows according to the sspf field, as defined by the configuration returned by seq_field().

Usage

ua_to_sspf(ua)

Arguments

ua

sf object containing analysis units

Value

An sf object where polygons and descriptive fields are aggregated at the SSPF level.

Details

In addition to summing surfaces, descriptive fields are preserved.

This function is used internally by seq_parcels(), but may be called directly when a SSPF-level summary of UA data is needed.