Create an empty sf object
create_empty_sf.RdThis function creates an empty sf object with the desired geometry type
(point, line, polygon, etc.).
Arguments
- geom_type
character; one of the geometry types supported bysf:POLYGON,LINESTRING,POINT,MULTIPOLYGON,MULTILINESTRING,MULTIPOINT.- ...
Named attributes with their classes. For example, you can pass arguments like
PLACETTE = character(0). Each argument must be named according to the attribute, with the corresponding empty vector of the appropriate class.