Download and cache cadastral data for legal entities ("Personnes Morales")
download_legal_entity.RdThis function downloads the official "Personnes Morales" datasets published by the French Ministry of Economy and Finance. These datasets contain cadastral and property information (parcels and buildings) owned by legal entities. The data are automatically cached locally to avoid repeated downloads.
Arguments
- cache
character; Storage directory. Defaults to the user cache directory (seetools::R_user_dir()).- verbose
logicalIfTRUE, display messages.
Examples
if (FALSE) { # \dontrun{
download_legal_entity(c(29, "08"))
} # }