Compute monthly precipitation, evapotranspiration and water balance from DRIAS projections
drias_etp.RdReads a DRIAS climate projection .txt file and computes the mean monthly
precipitation (P), potential evapotranspiration (ETP), and water balance (P - ETP)
for each projection period.
Arguments
- txt
character(1). Path to a DRIAS.txtfile downloaded from the DRIAS portal
Details
Invalid climate points (where precipitation or evapotranspiration are entirely equal to zero across all months) are automatically excluded to avoid biased averages.
Examples
if (FALSE) { # \dontrun{
txt <- "indicesRACMO22E_CNRM-CM5.txt"
etp <- drias_etp(txt)
head(etp)
} # }