Retrieve forest accessibility features (porter or skidder)
get_accessibility.RdBuilds a convex buffer around the input geometry and retrieves accessibility features for the requested machine type.
Usage
get_accessibility(
x,
type = c("porteur", "skidder"),
buffer = 1000,
verbose = TRUE
)