Retrieve administrative boundary polygons around an area
get_com_poly.RdBuilds a convex buffer around the input geometry, retrieves commune boundaries from BDTOPO, normalizes them, and returns a polygon layer.
get_com_poly.RdBuilds a convex buffer around the input geometry, retrieves commune boundaries from BDTOPO, normalizes them, and returns a polygon layer.