Retrieve and assemble hydrographic lines around an area
get_hydro_line.RdBuilds a convex buffer around the input geometry, retrieves hydrographic
line features from BDTOPO, normalizes them, and returns a combined sf
linestring layer.
get_hydro_line.RdBuilds a convex buffer around the input geometry, retrieves hydrographic
line features from BDTOPO, normalizes them, and returns a combined sf
linestring layer.