Retrieve and assemble hydrographic points around an area
get_hydro_point.RdBuilds a convex buffer around the input geometry, retrieves hydrographic
point features from BDTOPO, normalizes them, and returns a combined sf
point layer.
get_hydro_point.RdBuilds a convex buffer around the input geometry, retrieves hydrographic
point features from BDTOPO, normalizes them, and returns a combined sf
point layer.