poly_to_line.Rd
This function convert polygon to line and remove shared lines
poly_to_line(x)
sf POLYGONS, using a projected CRS
sf POLYGONS
An sf object with two MULTILINESTRING geometry is returned
sf
MULTILINESTRING
If the polygon layer contains topology errors (such as contiguous polygons not sharing exactly the same boundary)