Generate access point layer for a Sequoia project
seq_access.RdCreate an empty sf for access point features, and writes the resulting
layer to disk.
Value
Invisibly returns a named list of file paths written by seq_write().
Details
The access point layer is an empty layer : user must point access themselves.
The layer is written to disk using seq_write() with the key "v.access.entry.point".