Generate hypsometric curves line layer for a Sequoia project
seq_curves.RdRetrieves hypsometric curves line features intersecting and surrounding the project area and writes the resulting layer to disk.
Value
Invisibly returns a named list of file paths written by seq_write().
Returns NULL invisibly when no hypsometric curves features are found.
Details
Hypsometric curves line features are retrieved using get_curves().
If no hypsometric curves features are found, the function returns NULL
invisibly and no file is written.
When features are present, the layer is written to disk using
seq_write() with the key "v.curves.line".