Create geology layers for a Sequoia project from BRGM data
seq_geol.RdUses the project's PARCA layer to download geology datasets and clip them to its geometry.
Arguments
- dirname
characterDirectory where the matrice file is located. Defaults to the current working directory.- key
character. Optional geology layer identifier(s). IfNULL(default), all available geology layers are created. Available layers are"bdcharm50"and"carhab". Partial matching is supported (seeseq_key()).- cache
character; Storage directory. Defaults to the user cache directory (seetools::R_user_dir()).- verbose
logicalIfTRUE, display messages.- overwrite
logicalIfTRUE, overwrite zipfile.
Details
Layers and their associated QML style files are written to the
project directory using seq_write().
Difference between BRGM and CARHAB data
The BRGM 1:50000 geological maps are detailed, heterogeneous products created for geological interpretation. They include many finely split geological units and may show inconsistencies between neighbouring map sheets due to varying survey dates, methods, and levels of detail.
CARHAB data are a simplified, harmonised reinterpretation of these maps. Geological formations are recoded into broader lithological classes tailored for ecological modelling. The goal is to provide consistent, comparable, and ecologically relevant information across departments.
More info at infoterre