Download MNHN vector layers for a Sequoia project
seq_mnhn.RdDownloads one or several vector layers from the IGN WFS service
for mnhn layer(s) of a Sequoia project.
Usage
seq_mnhn(
dirname = ".",
buffer = 500,
key = get_keys("mnhn"),
verbose = TRUE,
overwrite = FALSE
)Arguments
- dirname
characterDirectory where the matrice file is located. Defaults to the current working directory.- buffer
numeric; Buffer aroundx(in meters) used to enlarge the download area.- key
character; List of MNHN layer identifiers to download. If not provided, the function usesget_keys("mnhn")to automatically select all MNHN layers defined in the Sequoia configuration (inst/config/seq_layers.yaml)- verbose
logical; IfTRUE, display messages.- overwrite
logicalIfTRUE, file is overwritten.
Value
A named list of file paths written by seq_write(), one per layer.
Details
This function is a convenience wrapper looping over get_mnhn(), allowing
the user to download all products in one call and automatically write them
to the project directory using seq_write().
For each value in key, the function attempts to query the corresponding
MNHN layer using get_mnhn().
If the layer contains features, it is written to the project directory via
seq_write()and recorded as a successful download.If the layer contains no features, it is skipped and marked as empty.