Download RGB and/or IRC orthophotos for a Sequoia project
seq_ortho.RdDownloads one or several orthophotos (RGB and/or IRC) from the IGN WMTS service
for the parca layer of a Sequoia project.
Usage
seq_ortho(
dirname = ".",
type = c("irc", "rgb"),
buffer = 200,
zoom = 12,
crs = 2154,
overwrite = FALSE,
verbose = TRUE
)Arguments
- dirname
characterDirectory where the matrice file is located. Defaults to the current working directory.- type
characterOne or several orthophoto types to download. Must be one or both of:"rgb"- true-color orthophoto"irc"- near-infrared orthophoto
- buffer
numeric; Buffer aroundx(in meters) used to enlarge the download area.- zoom
integerbetween 0 and 21. The smaller the zoom level, the less precise the resolution(seehappign::get_wmts())- crs
numericorcharacter; CRS of the returned raster (seehappign::get_wmts())- overwrite
logical; IfTRUE, file is overwritten.- verbose
logical; IfTRUE, display messages.
Value
A named list of file paths written by seq_write(), one per type.
Details
This function is a convenience wrapper looping over get_ortho(), allowing
the user to download both products in one call and automatically write them
to the project directory using seq_write().