Download, enrich and write cadastral geometries
seq_parca.RdThis function reads the matrice.xlsx file from a project directory,
downloads the geometry of each parcel, enriches the dataset with information
from the matrice, and writes the resulting layer to disk.
Details
The resulting object is returned invisibly as an sf polygons layer.
The output file is automatically written into the working directory defined
by dirname.
bdp_geom
The use and behaviour of bdp_geom are described in get_parca().
Automatic "lieu-dit" completion
If the function detects rows in the matrice where the field "LIEU_DIT"
is missing, the corresponding "lieu-dit" values will be downloaded
automatically and added to the output.
Existing "LIEU_DIT" values are never overwritten.