Create PF and SSPF object from UA for a Sequoia project
seq_parcels.RdThis function reads the UA polygon layer (v.seq.ua.poly) of a Sequoia
project, aggregates surfaces at the parcelle and
sous-parcelle level and writes four derived layers:
Value
A named list of six file paths, corresponding to the exported PF and SSPF polygon and line layers.
Details
Created layers are automatically written to the project directory using
seq_write(), respecting the dirname, overwrite, and verbose
parameters.
The function performs two levels of spatial aggregation ande create 4 layers:
PF (Parcelle) Rows of the UA are grouped using the
parcellefield, and corrected surface areas are summed. A polygon and border lines layer are created.SSPF (Sous-parcelle) Rows of the UA are grouped using the
parcelleandsous-parcellefield, and corrected surface areas are summed. A polygon and border lines layer are created.