Generate pedology polygon layer and associated PDF reports
seq_pedology.RdRetrieves pedology polygon features intersecting the project area, writes the resulting layer to disk and downloads associated pedology PDF reports into the project directory.
Value
Invisibly returns a named list of file paths written by seq_write().
Returns NULL invisibly when no pedology features are found.
Details
Pedology polygon features are retrieved using get_pedology().
If no pedology features intersect the project area, the function
returns NULL invisibly and no file is written.
When pedology features are present, the polygon layer is written
to disk using seq_write() with the key "v.sol.pedo.poly".
Associated UCS PDF reports are then downloaded into dirname
using get_pedology_pdf().