Generate graphic road layers for a Sequoia project
seq_roadway.RdCreate graphic road layers from a completed cadastral gaps layer.
Arguments
- source
characterSource layer key to use to generate polygon features. Must bev.cad.vides.polyorv.road.line.- dirname
characterPath to the project directory. Defaults to the current working directory.- verbose
logical; whether to display informational messages. Defaults toTRUE.- overwrite
logical; whether to overwrite existing files. Defaults toFALSE.
Value
Invisibly returns a named list of file paths written by seq_write().
Returns NULL invisibly when no features are created.
Details
Features are created from a completed cadastral gaps layer obtained by using
seq_voids().