Generates vegetation polygon, line and point layers for a Sequoia project.
seq_vege.RdThis function is a convenience wrapper around get_vege_poly(),
get_vege_line() and get_vege_point(), allowing the user to download
all products in one call and automatically write them to the project
directory using seq_write().
Value
A named list of file paths written by seq_write(),
one per vegetation layer.
Details
Each vegetation layer is always written to disk using seq_write(),
even when it contains no features (nrow == 0).