Write a spatial object based on a layer key
seq_write.RdWrite a spatial object based on a layer key
Arguments
- x
An
sfobject (for vector outputs) or aSpatRaster(for raster outputs).- key
characterName of a layer key to match against the entries defined ininst/config/seq_layers.yaml. (see Details for partial matching).- dirname
characterDirectory where the matrice file is located. Defaults to the current working directory.- id
character. Project identifier used to prefix the output filename. IfNULL, the identifier is automatically inferred. The function first attempts to extract a single, non-missing value from theIDENTIFIANTfield of layerx; if this fails, it then looks for a valid identifier in a*_matrice.xlsxfile found indirname. If no unique identifier can be determined, the filename is left unchanged.- verbose
logicalIfTRUE, display messages.- overwrite
logicalIfTRUE, file is overwritten.