Save Multiple Data Frames to an Excel Workbook with Styling
seq_xlsx.RdCreates a new Excel workbook, adds each element of a named list of data frames
as a separate sheet, writes the data, and applies style_table() to each sheet.
Arguments
- ...
data.frameEachdata.frameis wrote to a different sheet name. If...contain named arg, name is used as sheet name else variable name is used.- filename
characterFile path where the workbook will be saved.- data_table
logicalIfTRUE, data table is set up with total row. Default toFALSE.- overwrite
logicalIfTRUE, filename is overwritten.- verbose
logicalIfTRUE, display messages.