Check management unit (UG) consistency in the UA sf object
ua_check_ug.RdA management unit must (UG) can only have a single description. Therefore,
all units of analysis within the same UG must include the same descriptive
elements.
This function analyzes the consistency of the descriptive elements for each
management unit, and marks each row with a logical flag ug_valid
indicating whether it is consistent with the dominant description of the UG.